#
# spec file for package octave-forge-symbolic
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define octpkg  symbolic
Name:           octave-forge-%{octpkg}
Version:        2.6.0
Release:        lp150.1.4
Summary:        Octave Symbolic Package using SymPy
License:        GPL-3.0+
Group:          Productivity/Scientific/Math
Url:            http://octave.sourceforge.net
Source0:        http://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  octave-devel
BuildRequires:  python-devel
BuildRequires:  python-sympy >= 0.7.6
Requires:       octave-cli
Requires:       python-sympy >= 0.7.6

%description
Adds symbolic calculation features to GNU Octave.
These include common Computer Algebra System tools such as algebraic
operations, calculus, equation solving, Fourier and Laplace transforms,
variable precision arithmetic and and other features. Compatibility
with other symbolic toolboxes is a goal.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}

%changelog
* Fri Aug 18 2017 badshah400@gmail.com
- Update to version 2.6.0
  * New symbolic commands: ellipke, ellipticCE, ellipticCK,
    ellipticCPi, ellipticE, ellipticF, ellipticK, ellipticPi,
    harmonic, kroneckerDelta, pochhammer
  * New `@double` numerical functions; these are wrappers around
    SymPy, so they are slower than native floating-point
    implementations: harmonic.
  * Support for the new SymPy 1.1.1.
  * `solve` now supports vectors of equations and vectors of
    variables.
  * Better warning for `sym(0.1)`, updated docs about floating
    point.
  * Double values can now be converted to their exact rational
    value using `sym(0.1, 'f')`.  Passing `'r'` gives the current
    heuristic behaviour.  Neither raises a warning.
  * The default floating-point heuristics now check for square
    roots of integers, so `sym(sqrt(2))` should work.
  * `sym('i')` and `sym('I')` no longer create the imaginary unit:
    use `sym(i)` or `sym(1i)`.
  * `sym(e)` now gives the same as `exp(sym(1))`.  However,
    `sym('e')` and `syms e` continue to create a variable named
    `e`.
  * `sym` now accepts function handles such as anonymous functions
    as inputs.
  * `subs` is not approriate for numerical evaluation; add an
    example in `help subs` which shows how to do this with
    `function_handle`.
  * Calling `sym(cell)` now creates a sym array instead of a cell
    array. Old behaviour of creating a cell array was deprecated
    in 2.5.0.
  * Bug fix: isequal(n) for symfun's correctly tests the argnames.
* Tue Jun  7 2016 dmitry_r@opensuse.org
- Update to version 2.4.0
  * New symbolic commands:
    acsc, csch, gammaln, polylog, asec, dilog, hypergeom, psi,
    asech, ei, hypot, resize, besseljn, expint, igamma, sech,
    besselyn, ezsurf, jordan, signIm, cat, fresnelc, laguerreL,
    sinint, cosint, fresnels, lgamma, sinhint, coshint, gammainc,
    logint, ssinint
  * Move some functions from the "specfun" package:
    dirac, heaviside, laguerreL, lambertw
  * Re-implement @double/laguerreL for numerical stability.
  * Add spherical Bessel functions: these are called `besseljn` and
    `besselyn`.
* Wed Dec 23 2015 dmitry_r@opensuse.org
- Update to version 2.2.4
  * Bigfix release
* Fri Nov 27 2015 dmitry_r@opensuse.org
- Update to version 2.2.3
  * Bigfix release
* Tue Jul  7 2015 dmitry_r@opensuse.org
- Update to version 2.2.2
  * Bigfix release
* Tue Apr 28 2015 dmitry_r@opensuse.org
- Update to version 2.2.1
  * Fix an ascii pretty printing regression (issue #234).
  * Other minor fixes for doctests, sympref and symreplace.
* Wed Apr 22 2015 dmitry_r@opensuse.org
- Update to version 2.2.1
  * New commands:
    catalan eulergamma lambertw
  * Installing symbolic package now check for Python and minimum
    version of SymPy.
  * Installations from Octave-Forge ("pkg install -forge symbolic")
    should now work on Windows (thanks vassbu).  You will need the
    Python and SymPy dependencies.  Or you can use the [bundled
    package](https://github.com/cbm755/octsympy/releases)
  * Added support for Python 3 (still works with Python 2 as well).
  * Documentation improvements especially to assumptions.  Examples
    within documentation can now be tested with doctests, see the
    `octsympy_doctests.m` function.
  * Fix a warning on Octave 4.0.0-rc1 and make tests work properly.
  * Other bug fixes: assumptions; symvar and symbolic matrix powers;
    various display issues.
* Mon Mar  9 2015 dmitry_r@opensuse.org
- Update to version 2.1.0
  * New commands: columns, degree, formula, ismatrix, numden, rows
  * Additional ways of calling symsum, symprod, and subs for better
    compatibility with other symbolic toolboxes.
  * Bug fixes in poly2sym, sym2poly, symfun, prod, horner, coeffs.
  * Documentation improvements.
  * Improvements to "argnames" and "formula" for the dependent
    variables and dependent expression of a symfun.
  * Improvements to assumptions.
  * Improve symbolic sized matrices such as `A = sym('a', [n m])`.
  * Drop python_cmd_string, which has been deprecated since v0.1.1.
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 2.0.0
